@@ -47,6 +47,7 @@ GIT_MODE_TREE_STR = "040000"
 class AppArgs:
     """Represent script arguments common to all commands."""
 
+    solr_timeout: int
     solr_url: str
     debug: bool = False
 
@@ -64,11 +65,12 @@ env.read_env()  # read .env file, if it exists
 @app.callback()
 def main(
     debug: bool = typer.Option(False, help="Display DEBUG log messages."),
+    solr_timeout: int = typer.Option(env.int("SOLR_TIMEOUT", default=60), show_default=True),
     solr_url: str = typer.Option(env.str("SOLR_URL", default="http://localhost:8983/solr/dbnomics"), show_default=True),
 ):
     """Index DBnomics data to Solr."""
     global app_args
-    app_args = AppArgs(debug=debug, solr_url=solr_url)
+    app_args = AppArgs(debug=debug, solr_timeout=solr_timeout, solr_url=solr_url)
 
     # Setup logging
     daiquiri.setup()
@@ -97,7 +99,12 @@ def index_providers(
     storage_pool = FileSystemStoragePool(storage_base_dir)
     for storage in storage_pool.iter_storages():
         services.index_provider(
-            storage, delete_obsolete_series=delete_obsolete_series, force=force, limit=limit, solr_url=app_args.solr_url
+            storage,
+            delete_obsolete_series=delete_obsolete_series,
+            force=force,
+            limit=limit,
+            solr_timeout=app_args.solr_timeout,
+            solr_url=app_args.solr_url,
         )
 
 
@@ -143,6 +150,7 @@ def index_provider(
         delete_obsolete_series=delete_obsolete_series,
         force=force,
         limit=limit,
+        solr_timeout=app_args.solr_timeout,
         solr_url=app_args.solr_url,
     )
 
@@ -162,13 +170,12 @@ def delete_provider(
         typer.echo("one of 'code' or 'slug' options must be provided, but not both")
         raise typer.Abort()
 
-    dbnomics_solr_client = DBnomicsSolrClient(app_args.solr_url)
+    dbnomics_solr_client = DBnomicsSolrClient(app_args.solr_url, timeout=app_args.solr_timeout)
 
-    if provider_code is None and provider_slug is not None:
-        provider_code = dbnomics_solr_client.query_provider_by_slug(provider_slug)["code"]
-    assert isinstance(provider_code, str)
-
-    services.delete_provider_by_code(provider_code, dbnomics_solr_client=dbnomics_solr_client)
+    if provider_code is not None:
+        services.delete_provider_by_code(provider_code, dbnomics_solr_client=dbnomics_solr_client)
+    elif provider_slug is not None:
+        services.delete_provider_by_slug(provider_slug, dbnomics_solr_client=dbnomics_solr_client)
 
 
 def is_desired_dataset(dataset_code, datasets, excluded_datasets, start_from):
@@ -177,7 +184,7 @@ def is_desired_dataset(dataset_code, datasets, excluded_datasets, start_from):
         logger.debug("Skipping dataset %r because it is not mentioned by the --dataset option", dataset_code)
         return False
     if excluded_datasets and dataset_code in excluded_datasets:
-        logger.debug("Skipping dataset %r because it is mentioned by the --exclude-dataset " "option", dataset_code)
+        logger.debug("Skipping dataset %r because it is mentioned by the --exclude-dataset option", dataset_code)
         return False
     if start_from is not None and dataset_code < start_from:
         logger.debug("Skipping dataset %r because of the --start-from option", dataset_code)
